@@ -9,7 +9,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/AboutDialog.qml" line="45"/>
+        <location filename="../../src/maemo5/AboutDialog.qml" line="59"/>
         <source>A user-friendly internet radio player and client for the cuteRadio internet radio service.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -22,27 +22,27 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/AccountDialog.qml" line="32"/>
+        <location filename="../../src/maemo5/AccountDialog.qml" line="40"/>
         <source>Username</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/AccountDialog.qml" line="44"/>
+        <location filename="../../src/maemo5/AccountDialog.qml" line="54"/>
         <source>Password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/AccountDialog.qml" line="58"/>
+        <location filename="../../src/maemo5/AccountDialog.qml" line="76"/>
         <source>Done</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/AccountDialog.qml" line="79"/>
+        <location filename="../../src/maemo5/AccountDialog.qml" line="97"/>
         <source>You are signed in to cuteRadio</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/AccountDialog.qml" line="83"/>
+        <location filename="../../src/maemo5/AccountDialog.qml" line="101"/>
         <source>Cannot obtain access token</source>
         <translation type="unfinished"></translation>
     </message>
@@ -55,112 +55,112 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/AddStationDialog.qml" line="45"/>
+        <location filename="../../src/maemo5/AddStationDialog.qml" line="61"/>
         <source>Title</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/AddStationDialog.qml" line="57"/>
+        <location filename="../../src/maemo5/AddStationDialog.qml" line="75"/>
         <source>Description</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/AddStationDialog.qml" line="65"/>
+        <location filename="../../src/maemo5/AddStationDialog.qml" line="85"/>
         <source>Genre</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/AddStationDialog.qml" line="73"/>
+        <location filename="../../src/maemo5/AddStationDialog.qml" line="96"/>
         <source>Country</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/AddStationDialog.qml" line="81"/>
+        <location filename="../../src/maemo5/AddStationDialog.qml" line="107"/>
         <source>Language</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/AddStationDialog.qml" line="89"/>
+        <location filename="../../src/maemo5/AddStationDialog.qml" line="118"/>
         <source>Source</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/AddStationDialog.qml" line="104"/>
+        <location filename="../../src/maemo5/AddStationDialog.qml" line="140"/>
         <source>Done</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>CountriesPage</name>
+    <name>CountriesWindow</name>
     <message>
-        <location filename="../../src/maemo5/CountriesPage.qml" line="24"/>
+        <location filename="../../src/maemo5/CountriesWindow.qml" line="24"/>
         <source>Stations by country</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/CountriesPage.qml" line="31"/>
+        <location filename="../../src/maemo5/CountriesWindow.qml" line="31"/>
         <source>Reload</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/CountriesPage.qml" line="66"/>
+        <location filename="../../src/maemo5/CountriesWindow.qml" line="60"/>
         <source>No countries found</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>FavouritesPage</name>
+    <name>FavouritesWindow</name>
     <message>
-        <location filename="../../src/maemo5/FavouritesPage.qml" line="24"/>
+        <location filename="../../src/maemo5/FavouritesWindow.qml" line="24"/>
         <source>Favourite stations</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/FavouritesPage.qml" line="31"/>
+        <location filename="../../src/maemo5/FavouritesWindow.qml" line="31"/>
         <source>Reload</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/FavouritesPage.qml" line="53"/>
+        <location filename="../../src/maemo5/FavouritesWindow.qml" line="53"/>
         <source>Show details</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/FavouritesPage.qml" line="74"/>
-        <source>Add to &apos;My stations&apos;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/FavouritesPage.qml" line="125"/>
-        <location filename="../../src/maemo5/FavouritesPage.qml" line="163"/>
-        <source>Station added to &apos;My stations&apos;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/FavouritesPage.qml" line="63"/>
+        <location filename="../../src/maemo5/FavouritesWindow.qml" line="58"/>
         <source>Delete from favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/FavouritesPage.qml" line="107"/>
+        <location filename="../../src/maemo5/FavouritesWindow.qml" line="63"/>
+        <source>Add to &apos;My stations&apos;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/maemo5/FavouritesWindow.qml" line="76"/>
         <source>No stations found</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../src/maemo5/FavouritesWindow.qml" line="123"/>
+        <location filename="../../src/maemo5/FavouritesWindow.qml" line="161"/>
+        <source>Station added to &apos;My stations&apos;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
-    <name>GenresPage</name>
+    <name>GenresWindow</name>
     <message>
-        <location filename="../../src/maemo5/GenresPage.qml" line="24"/>
+        <location filename="../../src/maemo5/GenresWindow.qml" line="24"/>
         <source>Stations by genre</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/GenresPage.qml" line="31"/>
+        <location filename="../../src/maemo5/GenresWindow.qml" line="31"/>
         <source>Reload</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/GenresPage.qml" line="66"/>
+        <location filename="../../src/maemo5/GenresWindow.qml" line="60"/>
         <source>No genres found</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1127,96 +1127,96 @@
     </message>
 </context>
 <context>
-    <name>LanguagesPage</name>
+    <name>LanguagesWindow</name>
     <message>
-        <location filename="../../src/maemo5/LanguagesPage.qml" line="24"/>
+        <location filename="../../src/maemo5/LanguagesWindow.qml" line="24"/>
         <source>Stations by language</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/LanguagesPage.qml" line="31"/>
+        <location filename="../../src/maemo5/LanguagesWindow.qml" line="31"/>
         <source>Reload</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/LanguagesPage.qml" line="66"/>
+        <location filename="../../src/maemo5/LanguagesWindow.qml" line="60"/>
         <source>No languages found</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>MyStationsPage</name>
+    <name>MyStationsWindow</name>
     <message>
-        <location filename="../../src/maemo5/MyStationsPage.qml" line="24"/>
+        <location filename="../../src/maemo5/MyStationsWindow.qml" line="24"/>
         <source>My stations</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/MyStationsPage.qml" line="31"/>
+        <location filename="../../src/maemo5/MyStationsWindow.qml" line="31"/>
         <source>Reload</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/MyStationsPage.qml" line="36"/>
+        <location filename="../../src/maemo5/MyStationsWindow.qml" line="36"/>
         <source>Add station</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/MyStationsPage.qml" line="61"/>
+        <location filename="../../src/maemo5/MyStationsWindow.qml" line="58"/>
         <source>Show details</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/MyStationsPage.qml" line="71"/>
+        <location filename="../../src/maemo5/MyStationsWindow.qml" line="63"/>
         <source>Edit details</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/MyStationsPage.qml" line="90"/>
+        <location filename="../../src/maemo5/MyStationsWindow.qml" line="68"/>
         <source>Delete from &apos;My stations&apos;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/MyStationsPage.qml" line="129"/>
-        <source>Station updated</source>
+        <location filename="../../src/maemo5/MyStationsWindow.qml" line="81"/>
+        <source>No stations found</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/MyStationsPage.qml" line="114"/>
-        <source>No stations found</source>
+        <location filename="../../src/maemo5/MyStationsWindow.qml" line="122"/>
+        <source>Station updated</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>NameCountDelegate</name>
     <message>
-        <location filename="../../src/maemo5/NameCountDelegate.qml" line="60"/>
+        <location filename="../../src/maemo5/NameCountDelegate.qml" line="45"/>
         <source>stations</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>NowPlayingAction</name>
+    <name>NowPlayingMenuItem</name>
     <message>
-        <location filename="../../src/maemo5/NowPlayingAction.qml" line="28"/>
+        <location filename="../../src/maemo5/NowPlayingMenuItem.qml" line="29"/>
         <source>(unknown song)</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>NowPlayingPage</name>
+    <name>NowPlayingWindow</name>
     <message>
-        <location filename="../../src/maemo5/NowPlayingPage.qml" line="63"/>
+        <location filename="../../src/maemo5/NowPlayingWindow.qml" line="68"/>
         <source>(unknown artist) / (unknown song)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/NowPlayingPage.qml" line="82"/>
+        <location filename="../../src/maemo5/NowPlayingWindow.qml" line="89"/>
         <source>Buffering</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/NowPlayingPage.qml" line="113"/>
+        <location filename="../../src/maemo5/NowPlayingWindow.qml" line="133"/>
         <source>(unknown genre)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1229,79 +1229,79 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/PlayUrlDialog.qml" line="29"/>
+        <location filename="../../src/maemo5/PlayUrlDialog.qml" line="35"/>
         <source>URL</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/PlayUrlDialog.qml" line="38"/>
+        <location filename="../../src/maemo5/PlayUrlDialog.qml" line="50"/>
         <source>Done</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/PlayUrlDialog.qml" line="45"/>
+        <location filename="../../src/maemo5/PlayUrlDialog.qml" line="58"/>
         <source>(unknown station)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/PlayUrlDialog.qml" line="47"/>
+        <location filename="../../src/maemo5/PlayUrlDialog.qml" line="60"/>
         <source>(unknown genre)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/PlayUrlDialog.qml" line="48"/>
+        <location filename="../../src/maemo5/PlayUrlDialog.qml" line="61"/>
         <source>(unknown country)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/PlayUrlDialog.qml" line="49"/>
+        <location filename="../../src/maemo5/PlayUrlDialog.qml" line="62"/>
         <source>(unknown language)</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>RecentlyPlayedPage</name>
+    <name>RecentlyPlayedWindow</name>
     <message>
-        <location filename="../../src/maemo5/RecentlyPlayedPage.qml" line="24"/>
+        <location filename="../../src/maemo5/RecentlyPlayedWindow.qml" line="24"/>
         <source>Recently played stations</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/RecentlyPlayedPage.qml" line="31"/>
+        <location filename="../../src/maemo5/RecentlyPlayedWindow.qml" line="31"/>
         <source>Reload</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/RecentlyPlayedPage.qml" line="53"/>
+        <location filename="../../src/maemo5/RecentlyPlayedWindow.qml" line="53"/>
         <source>Show details</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/RecentlyPlayedPage.qml" line="79"/>
-        <source>Add to &apos;My stations&apos;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/RecentlyPlayedPage.qml" line="130"/>
-        <location filename="../../src/maemo5/RecentlyPlayedPage.qml" line="175"/>
-        <source>Station added to &apos;My stations&apos;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/RecentlyPlayedPage.qml" line="64"/>
+        <location filename="../../src/maemo5/RecentlyPlayedWindow.qml" line="58"/>
         <source>Delete from favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/RecentlyPlayedPage.qml" line="64"/>
+        <location filename="../../src/maemo5/RecentlyPlayedWindow.qml" line="59"/>
         <source>Add to favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/RecentlyPlayedPage.qml" line="112"/>
+        <location filename="../../src/maemo5/RecentlyPlayedWindow.qml" line="67"/>
+        <source>Add to &apos;My stations&apos;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/maemo5/RecentlyPlayedWindow.qml" line="80"/>
         <source>No stations found</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../src/maemo5/RecentlyPlayedWindow.qml" line="127"/>
+        <location filename="../../src/maemo5/RecentlyPlayedWindow.qml" line="172"/>
+        <source>Station added to &apos;My stations&apos;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ScreenOrientationModel</name>
@@ -1332,7 +1332,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/SearchDialog.qml" line="34"/>
+        <location filename="../../src/maemo5/SearchDialog.qml" line="43"/>
         <source>Search query</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1342,94 +1342,79 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/SearchDialog.qml" line="97"/>
+        <location filename="../../src/maemo5/SearchDialog.qml" line="103"/>
         <source>Done</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>SearchPage</name>
+    <name>SearchWindow</name>
     <message>
-        <location filename="../../src/maemo5/SearchPage.qml" line="33"/>
-        <source>Reload</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/SearchPage.qml" line="55"/>
-        <source>Show details</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/SearchPage.qml" line="81"/>
-        <source>Add to &apos;My stations&apos;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/SearchPage.qml" line="132"/>
-        <location filename="../../src/maemo5/SearchPage.qml" line="177"/>
-        <source>Station added to &apos;My stations&apos;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/SearchPage.qml" line="66"/>
-        <source>Delete from favourites</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/SearchPage.qml" line="26"/>
+        <location filename="../../src/maemo5/SearchWindow.qml" line="26"/>
         <source>Search</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/SearchPage.qml" line="66"/>
+        <location filename="../../src/maemo5/SearchWindow.qml" line="33"/>
+        <source>Reload</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/maemo5/SearchWindow.qml" line="55"/>
+        <source>Show details</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/maemo5/SearchWindow.qml" line="60"/>
+        <source>Delete from favourites</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/maemo5/SearchWindow.qml" line="61"/>
         <source>Add to favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/SearchPage.qml" line="114"/>
+        <location filename="../../src/maemo5/SearchWindow.qml" line="69"/>
+        <source>Add to &apos;My stations&apos;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/maemo5/SearchWindow.qml" line="82"/>
         <source>No stations found</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../src/maemo5/SearchWindow.qml" line="129"/>
+        <location filename="../../src/maemo5/SearchWindow.qml" line="174"/>
+        <source>Station added to &apos;My stations&apos;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../../src/maemo5/SettingsDialog.qml" line="36"/>
-        <source>Media</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/SettingsDialog.qml" line="40"/>
-        <source>Sleep timer duration</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/SettingsDialog.qml" line="48"/>
-        <source>mins</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/SettingsDialog.qml" line="54"/>
+        <location filename="../../src/maemo5/SettingsDialog.qml" line="69"/>
         <source>Send played stations data</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/SettingsDialog.qml" line="59"/>
-        <source>Other</source>
+        <location filename="../../src/maemo5/SettingsDialog.qml" line="52"/>
+        <source>Sleep timer duration (mins)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/SettingsDialog.qml" line="65"/>
+        <location filename="../../src/maemo5/SettingsDialog.qml" line="76"/>
         <source>Screen orientation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/SettingsDialog.qml" line="78"/>
+        <location filename="../../src/maemo5/SettingsDialog.qml" line="84"/>
         <source>Language</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/SettingsDialog.qml" line="92"/>
+        <location filename="../../src/maemo5/SettingsDialog.qml" line="98"/>
         <source>Done</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1440,29 +1425,29 @@
     </message>
 </context>
 <context>
-    <name>SleepTimerAction</name>
+    <name>SleepTimerMenuItem</name>
     <message>
-        <location filename="../../src/maemo5/SleepTimerAction.qml" line="24"/>
+        <location filename="../../src/maemo5/SleepTimerMenuItem.qml" line="27"/>
         <source>Sleep timer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/SleepTimerAction.qml" line="25"/>
+        <location filename="../../src/maemo5/SleepTimerMenuItem.qml" line="28"/>
         <source>Off</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/SleepTimerAction.qml" line="30"/>
+        <location filename="../../src/maemo5/SleepTimerMenuItem.qml" line="34"/>
         <source>Sleep timer set for</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/SleepTimerAction.qml" line="31"/>
+        <location filename="../../src/maemo5/SleepTimerMenuItem.qml" line="35"/>
         <source>minutes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/SleepTimerAction.qml" line="32"/>
+        <location filename="../../src/maemo5/SleepTimerMenuItem.qml" line="36"/>
         <source>Sleep timer disabled</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1483,144 +1468,144 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/StationDetailsDialog.qml" line="48"/>
+        <location filename="../../src/maemo5/StationDetailsDialog.qml" line="58"/>
         <source>Title</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/StationDetailsDialog.qml" line="58"/>
+        <location filename="../../src/maemo5/StationDetailsDialog.qml" line="70"/>
         <source>Description</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/StationDetailsDialog.qml" line="63"/>
+        <location filename="../../src/maemo5/StationDetailsDialog.qml" line="76"/>
         <source>No description</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/StationDetailsDialog.qml" line="68"/>
+        <location filename="../../src/maemo5/StationDetailsDialog.qml" line="82"/>
         <source>Genre</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/StationDetailsDialog.qml" line="78"/>
+        <location filename="../../src/maemo5/StationDetailsDialog.qml" line="94"/>
         <source>Country</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/StationDetailsDialog.qml" line="88"/>
+        <location filename="../../src/maemo5/StationDetailsDialog.qml" line="106"/>
         <source>Language</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/StationDetailsDialog.qml" line="98"/>
+        <location filename="../../src/maemo5/StationDetailsDialog.qml" line="118"/>
         <source>Source</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/StationDetailsDialog.qml" line="108"/>
+        <location filename="../../src/maemo5/StationDetailsDialog.qml" line="130"/>
         <source>Last played</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/StationDetailsDialog.qml" line="113"/>
+        <location filename="../../src/maemo5/StationDetailsDialog.qml" line="136"/>
         <source>Never</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>StationsPage</name>
+    <name>StationsWindow</name>
     <message>
-        <location filename="../../src/maemo5/StationsPage.qml" line="30"/>
+        <location filename="../../src/maemo5/StationsWindow.qml" line="30"/>
         <source>Reload</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/StationsPage.qml" line="52"/>
+        <location filename="../../src/maemo5/StationsWindow.qml" line="52"/>
         <source>Show details</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/StationsPage.qml" line="78"/>
-        <source>Add to &apos;My stations&apos;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/StationsPage.qml" line="129"/>
-        <location filename="../../src/maemo5/StationsPage.qml" line="174"/>
-        <source>Station added to &apos;My stations&apos;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/StationsPage.qml" line="63"/>
+        <location filename="../../src/maemo5/StationsWindow.qml" line="57"/>
         <source>Delete from favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/StationsPage.qml" line="63"/>
+        <location filename="../../src/maemo5/StationsWindow.qml" line="58"/>
         <source>Add to favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/StationsPage.qml" line="111"/>
+        <location filename="../../src/maemo5/StationsWindow.qml" line="66"/>
+        <source>Add to &apos;My stations&apos;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/maemo5/StationsWindow.qml" line="79"/>
         <source>No stations found</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../src/maemo5/StationsWindow.qml" line="126"/>
+        <location filename="../../src/maemo5/StationsWindow.qml" line="171"/>
+        <source>Station added to &apos;My stations&apos;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Utils</name>
     <message>
-        <location filename="../../src/base/utils.cpp" line="76"/>
+        <location filename="../../src/base/utils.cpp" line="72"/>
         <source>Bad request</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/utils.cpp" line="78"/>
+        <location filename="../../src/base/utils.cpp" line="74"/>
         <source>Request is unauthorised</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/utils.cpp" line="80"/>
+        <location filename="../../src/base/utils.cpp" line="76"/>
         <source>Request is forbidden</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/utils.cpp" line="82"/>
+        <location filename="../../src/base/utils.cpp" line="78"/>
         <source>Requested resource is unavailable</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/utils.cpp" line="84"/>
+        <location filename="../../src/base/utils.cpp" line="80"/>
         <source>Requested resource is not accessible</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/utils.cpp" line="86"/>
+        <location filename="../../src/base/utils.cpp" line="82"/>
         <source>Request cannot be processed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/utils.cpp" line="88"/>
+        <location filename="../../src/base/utils.cpp" line="84"/>
         <source>Request limit has been reached. Please try again later</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/utils.cpp" line="90"/>
+        <location filename="../../src/base/utils.cpp" line="86"/>
         <source>Internal server error. Please try again later</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/utils.cpp" line="92"/>
+        <location filename="../../src/base/utils.cpp" line="88"/>
         <source>Service unavailable. Please try again later</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/utils.cpp" line="94"/>
+        <location filename="../../src/base/utils.cpp" line="90"/>
         <source>Request timed out. Please try again later</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/utils.cpp" line="96"/>
+        <location filename="../../src/base/utils.cpp" line="92"/>
         <source>Unknown error. Please try again later</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1628,62 +1613,62 @@
 <context>
     <name>main</name>
     <message>
-        <location filename="../../src/maemo5/main.qml" line="32"/>
+        <location filename="../../src/maemo5/main.qml" line="33"/>
         <source>Play URL</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/main.qml" line="40"/>
+        <location filename="../../src/maemo5/main.qml" line="38"/>
         <source>Search</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/main.qml" line="49"/>
+        <location filename="../../src/maemo5/main.qml" line="44"/>
         <source>Account</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/main.qml" line="58"/>
+        <location filename="../../src/maemo5/main.qml" line="50"/>
         <source>Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/main.qml" line="66"/>
+        <location filename="../../src/maemo5/main.qml" line="55"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/main.qml" line="102"/>
+        <location filename="../../src/maemo5/main.qml" line="69"/>
         <source>Please login or register a cuteRadio account</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/main.qml" line="109"/>
+        <location filename="../../src/maemo5/main.qml" line="76"/>
         <source>All stations</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/main.qml" line="211"/>
+        <location filename="../../src/maemo5/main.qml" line="221"/>
         <source>(unknown station)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/main.qml" line="213"/>
+        <location filename="../../src/maemo5/main.qml" line="223"/>
         <source>(unknown genre)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/main.qml" line="214"/>
+        <location filename="../../src/maemo5/main.qml" line="224"/>
         <source>(unknown country)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/main.qml" line="215"/>
+        <location filename="../../src/maemo5/main.qml" line="225"/>
         <source>(unknown language)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/main.qml" line="271"/>
+        <location filename="../../src/maemo5/main.qml" line="290"/>
         <source>Retrieving the stream URL from the playlist</source>
         <translation type="unfinished"></translation>
     </message>
